==> librenms-1.67v0.tgz: librenms/includes/discovery/sensors/current/adva_fsp3kr7.inc.php <==
<?php
/**
 * LibreNMS - ADVA device support - Current
 *
 * @category   Network_Monitoring
 * @package    LibreNMS
 * @subpackage ADVA device support
 * @author     Christoph Zilian <czilian@hotmail.com>
 * @license    http://gnu.org/copyleft/gpl.html GNU GPL
 * @link       https://github.com/librenms/librenms/

 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.  Please see LICENSE.txt at the top level of
 * the source code distribution for details.
 **/

// *************************************************************
// ***** Sensors for ADVA FSP3000 R7
// *************************************************************

    $multiplier = 1;
    $divisor    = 1000;

if (is_array($pre_cache['adva_fsp3kr7_Card'])) {
    foreach (array_keys($pre_cache['adva_fsp3kr7_Card']) as $index) {
        if ($pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuAmpere']) {
            $oid          = '.1.3.6.1.4.1.2544.1.11.11.1.2.1.1.1.6.'.$index;
            $descr        = strtoupper($pre_cache['adva_fsp3kr7_Card'][$index]['entityEqptAidString'])." Input";
            $current      = $pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuAmpere']/$divisor;

            discover_sensor(
                $valid['sensor'],
                'current',
                $device,
                $oid,
                'eqptPhysInstValuePsuAmpere'.$index,
                'adva_fsp3kr7',
                $descr,
                $divisor,
                $multiplier,
                null,
                null,
                null,
                null,
                $current
            );
        }
    }
}// ******** End If of FSP3000 R7

==> librenms-21.1.0v0.tgz: librenms/includes/discovery/sensors/current/adva_fsp3kr7.inc.php <==
<?php
/**
 * LibreNMS - ADVA device support - Current
 *
 * @category   Network_Monitoring
 * @author     Christoph Zilian <czilian@hotmail.com>
 * @license    http://gnu.org/copyleft/gpl.html GNU GPL
 * @link       https://github.com/librenms/librenms/
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.  Please see LICENSE.txt at the top level of
 * the source code distribution for details.
 **/

// *************************************************************
// ***** Sensors for ADVA FSP3000 R7
// *************************************************************

    $multiplier = 1;
    $divisor = 1000;

if (is_array($pre_cache['adva_fsp3kr7_Card'])) {
    foreach (array_keys($pre_cache['adva_fsp3kr7_Card']) as $index) {
        if ($pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuAmpere']) {
            $oid = '.1.3.6.1.4.1.2544.1.11.11.1.2.1.1.1.6.' . $index;
            $descr = strtoupper($pre_cache['adva_fsp3kr7_Card'][$index]['entityEqptAidString']) . ' Input';
            $current = $pre_cache['adva_fsp3kr7_Card'][$index]['eqptPhysInstValuePsuAmpere'] / $divisor;

            discover_sensor(
                $valid['sensor'],
                'current',
                $device,
                $oid,
                'eqptPhysInstValuePsuAmpere' . $index,
                'adva_fsp3kr7',
                $descr,
                $divisor,
                $multiplier,
                null,
                null,
                null,
                null,
                $current
            );
        }
    }
}// ******** End If of FSP3000 R7
